package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class Attribute extends ASN1Encodable {
   private DERObjectIdentifier attrType;
   private ASN1Set attrValues;

   public static Attribute getInstance(Object o) {
      if (o != null && !(o instanceof Attribute)) {
         if (o instanceof ASN1Sequence) {
            return new Attribute((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + o.getClass().getName());
         }
      } else {
         return (Attribute)o;
      }
   }

   public Attribute(ASN1Sequence seq) {
      if (seq.size() == 2) {
         this.attrType = DERObjectIdentifier.getInstance(seq.getObjectAt(0));
         this.attrValues = ASN1Set.getInstance(seq.getObjectAt(1));
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public Attribute(DERObjectIdentifier attrType, ASN1Set attrValues) {
      this.attrType = attrType;
      this.attrValues = attrValues;
   }

   public DERObjectIdentifier getAttrType() {
      return this.attrType;
   }

   public ASN1Set getAttrValues() {
      return this.attrValues;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.attrType);
      var10000.add(this.attrValues);
      return new DERSequence(var1);
   }
}
